@@ -1,9 +1,12 @@
 from .chat import Chat, AsyncChat
 from .context import Context, AsyncContext
+from .batch_chat import BatchChat, AsyncBatchChat
 
 __all__ = [
     "Chat",
     "AsyncChat",
     "Context",
     "AsyncContext",
+    "BatchChat",
+    "AsyncBatchChat"
 ]
